==> firefox-61.0b6.source.tar.xz: firefox-61.0/browser/extensions/activity-stream/prerendered/locales/gl/activity-stream-strings.js <==
// Note - this is a generated gl file.
window.gActivityStreamStrings = {
  "newtab_page_title": "Nova lapela",
  "header_top_sites": "Sitios favoritos",
  "header_highlights": "Destacados",
  "header_recommended_by": "Recomendado por {provider}",
  "context_menu_button_sr": "Abrir o menú contextual para {title}",
  "section_context_menu_button_sr": "Abrir o menú contextual da sección",
  "type_label_visited": "Visitados",
  "type_label_bookmarked": "Nos marcadores",
  "type_label_recommended": "Tendencias",
  "type_label_pocket": "Gardado no Pocket",
  "type_label_downloaded": "Descargado",
  "menu_action_bookmark": "Engadir aos marcadores",
  "menu_action_remove_bookmark": "Retirar marcador",
  "menu_action_open_new_window": "Abrir nunha nova xanela",
  "menu_action_open_private_window": "Abrir nunha nova xanela privada",
  "menu_action_dismiss": "Rexeitar",
  "menu_action_delete": "Eliminar do historial",
  "menu_action_pin": "Fixar",
  "menu_action_unpin": "Quitar",
  "confirm_history_delete_p1": "Confirma que quere eliminar do historial todas as instancias desta páxina?",
  "confirm_history_delete_notice_p2": "Non é posíbel desfacer esta acción.",
  "menu_action_save_to_pocket": "Gardar en Pocket",
  "menu_action_delete_pocket": "Eliminar do Pocket",
  "menu_action_archive_pocket": "Arquivar no Pocket",
  "menu_action_show_file_mac_os": "Amosar no Finder",
  "menu_action_show_file_windows": "Abrir o cartafol que o contén",
  "menu_action_show_file_linux": "Abrir o cartafol que o contén",
  "menu_action_show_file_default": "Amosar o ficheiro",
  "menu_action_open_file": "Abrir o ficheiro",
  "menu_action_copy_download_link": "Copiar ligazón de descarga",
  "menu_action_go_to_download_page": "Ir á páxina de descargas",
  "menu_action_remove_download": "Retirar do historial",
  "search_button": "Buscar",
  "search_header": "Busca de {search_engine_name}",
  "search_web_placeholder": "Buscar na Web",
  "section_disclaimer_topstories": "As historias máis interesantes da web, seleccionadas en función do que vostede lee. Grazas a Pocket, que agora é parte de Mozilla.",
  "section_disclaimer_topstories_linktext": "Coñeza como funciona.",
  "section_disclaimer_topstories_buttontext": "Entendín",
  "prefs_home_header": "Contido da páxina de inicio de Firefox",
  "prefs_home_description": "Escolla o contido que quere na pantalla de inicio de Firefox.",
  "prefs_section_rows_option": "{num} fila;{num} filas",
  "prefs_search_header": "Busca na web",
  "prefs_topsites_description": "Os sitios que máis visita",
  "prefs_topstories_description2": "Os mellores contidos dispoñíbeis na web, personalizados para vostede",
  "prefs_topstories_options_sponsored_label": "Historias patrocinadas",
  "prefs_topstories_sponsored_learn_more": "Máis información",
  "prefs_highlights_description": "Unha selección de sitios que gardou ou visitou",
  "prefs_highlights_options_visited_label": "Páxinas visitadas",
  "prefs_highlights_options_download_label": "A descarga máis recente",
  "prefs_highlights_options_pocket_label": "Páxinas gardadas en Pocket",
  "prefs_snippets_description": "Actualizacións de Mozilla e Firefox",
  "settings_pane_button_label": "Personalice a páxina de nova lapela",
  "settings_pane_topsites_header": "Sitios favoritos",
  "settings_pane_highlights_header": "Destacados",
  "settings_pane_highlights_options_bookmarks": "Marcadores",
  "settings_pane_snippets_header": "Fragmentos",
  "edit_topsites_button_text": "Editar",
  "edit_topsites_edit_button": "Editar este sitio",
  "topsites_form_add_header": "Novo sitio favorito",
  "topsites_form_edit_header": "Editar sitio favorito",
  "topsites_form_title_label": "Título",
  "topsites_form_title_placeholder": "Escribir un título",
  "topsites_form_url_label": "URL",
  "topsites_form_image_url_label": "URL da imaxe personalizada",
  "topsites_form_url_placeholder": "Escribir ou pegar un URL",
  "topsites_form_use_image_link": "Usar unha imaxe personalizada…",
  "topsites_form_preview_button": "Previsualizar",
  "topsites_form_add_button": "Engadir",
  "topsites_form_save_button": "Gardar",
  "topsites_form_cancel_button": "Cancelar",
  "topsites_form_url_validation": "Requírese un URL válido",
  "topsites_form_image_validation": "Produciuse un fallo ao cargar a imaxe. Probe un URL diferente.",
  "pocket_read_more": "Temas populares:",
  "pocket_read_even_more": "Ver máis historias",
  "highlights_empty_state": "Comece a navegar e aquí amosarémoslle algúns dos mellores artigos, vídeos e outras páxinas que visitara recentemente ou que engadira aos marcadores.",
  "topstories_empty_state": "Xa está ao día. Regrese máis tarde para ver máis historias de {provider}. Non pode agardar? Seleccione un tema popular e atopará máis historias interesantes da web.",
  "manual_migration_explanation2": "Probe Firefox cos marcadores, historial e contrasinais doutro navegador.",
  "manual_migration_cancel_button": "Non, grazas",
  "manual_migration_import_button": "Importar agora",
  "error_fallback_default_info": "Vaites, produciuse un erro ao cargar este contido.",
  "error_fallback_default_refresh_suggestion": "Actualice a páxina para tentalo de novo.",
  "section_menu_action_remove_section": "Retirar sección",
  "section_menu_action_collapse_section": "Contraer sección",
  "section_menu_action_expand_section": "Expandir sección",
  "section_menu_action_manage_section": "Xestionar sección",
  "section_menu_action_add_topsite": "Engadir sitio favorito",
  "section_menu_action_move_up": "Subir",
  "section_menu_action_move_down": "Baixar",
  "section_menu_action_privacy_notice": "Política de privacidade",
  "prefs_restore_defaults_button": "Restaurar a configuración predeterminada",
  "settings_pane_header": "Preferencias de nova lapela",
  "settings_pane_body2": "Escolla que quere ver nesta páxina.",
  "settings_pane_search_header": "Busca",
  "settings_pane_search_body": "Busca na web dende a nova lapela.",
  "settings_pane_topsites_body": "Acceda aos sitios web que máis visita.",
  "settings_pane_topsites_options_showmore": "Amosar dúas filas",
  "settings_pane_highlights_body2": "Atope algunhas páxinas interesantes que vostede xa visitou ou marcou recentemente.",
  "settings_pane_highlights_options_visited": "Sitios visitados",
  "settings_pane_snippets_body": "Lea noticias curtas de Mozilla sobre o Firefox, a cultura de Internet, e ocasionalmente, algún meme.",
  "settings_pane_done_button": "Feito",
  "settings_pane_topstories_options_sponsored": "Amosar historias patrocinadas",
  "pocket_description": "Grazas a Pocket, que agora forma parte de Mozilla, poderá descubrir contido de gran calidade que doutra forma se perdería."
};

==> firefox-62.0b14.source.tar.xz: firefox-62.0/browser/extensions/activity-stream/prerendered/locales/gl/activity-stream-strings.js <==
// Note - this is a generated gl file.
window.gActivityStreamStrings = {
  "newtab_page_title": "Nova lapela",
  "header_top_sites": "Sitios favoritos",
  "header_highlights": "Destacados",
  "header_recommended_by": "Recomendado por {provider}",
  "context_menu_button_sr": "Abrir o menú contextual para {title}",
  "section_context_menu_button_sr": "Abrir o menú contextual da sección",
  "type_label_visited": "Visitados",
  "type_label_bookmarked": "Nos marcadores",
  "type_label_recommended": "Tendencias",
  "type_label_pocket": "Gardado no Pocket",
  "type_label_downloaded": "Descargado",
  "menu_action_bookmark": "Engadir aos marcadores",
  "menu_action_remove_bookmark": "Retirar marcador",
  "menu_action_open_new_window": "Abrir nunha nova xanela",
  "menu_action_open_private_window": "Abrir nunha nova xanela privada",
  "menu_action_dismiss": "Rexeitar",
  "menu_action_delete": "Eliminar do historial",
  "menu_action_pin": "Fixar",
  "menu_action_unpin": "Quitar",
  "confirm_history_delete_p1": "Confirma que quere eliminar do historial todas as instancias desta páxina?",
  "confirm_history_delete_notice_p2": "Non é posíbel desfacer esta acción.",
  "menu_action_save_to_pocket": "Gardar en Pocket",
  "menu_action_delete_pocket": "Eliminar do Pocket",
  "menu_action_archive_pocket": "Arquivar no Pocket",
  "menu_action_show_file_mac_os": "Amosar no Finder",
  "menu_action_show_file_windows": "Abrir o cartafol que o contén",
  "menu_action_show_file_linux": "Abrir o cartafol que o contén",
  "menu_action_show_file_default": "Amosar o ficheiro",
  "menu_action_open_file": "Abrir o ficheiro",
  "menu_action_copy_download_link": "Copiar ligazón de descarga",
  "menu_action_go_to_download_page": "Ir á páxina de descargas",
  "menu_action_remove_download": "Retirar do historial",
  "search_button": "Buscar",
  "search_header": "Busca de {search_engine_name}",
  "search_web_placeholder": "Buscar na Web",
  "section_disclaimer_topstories": "As historias máis interesantes da web, seleccionadas en función do que vostede lee. Grazas a Pocket, que agora é parte de Mozilla.",
  "section_disclaimer_topstories_linktext": "Coñeza como funciona.",
  "section_disclaimer_topstories_buttontext": "Entendín",
  "prefs_home_header": "Contido da páxina de inicio de Firefox",
  "prefs_home_description": "Escolla o contido que quere na pantalla de inicio de Firefox.",
  "prefs_section_rows_option": "{num} fila;{num} filas",
  "prefs_search_header": "Busca na web",
  "prefs_topsites_description": "Os sitios que máis visita",
  "prefs_topstories_description2": "Os mellores contidos dispoñíbeis na web, personalizados para vostede",
  "prefs_topstories_options_sponsored_label": "Historias patrocinadas",
  "prefs_topstories_sponsored_learn_more": "Máis información",
  "prefs_highlights_description": "Unha selección de sitios que gardou ou visitou",
  "prefs_highlights_options_visited_label": "Páxinas visitadas",
  "prefs_highlights_options_download_label": "A descarga máis recente",
  "prefs_highlights_options_pocket_label": "Páxinas gardadas en Pocket",
  "prefs_snippets_description": "Actualizacións de Mozilla e Firefox",
  "settings_pane_button_label": "Personalice a páxina de nova lapela",
  "settings_pane_topsites_header": "Sitios favoritos",
  "settings_pane_highlights_header": "Destacados",
  "settings_pane_highlights_options_bookmarks": "Marcadores",
  "settings_pane_snippets_header": "Fragmentos",
  "edit_topsites_button_text": "Editar",
  "edit_topsites_edit_button": "Editar este sitio",
  "topsites_form_add_header": "Novo sitio favorito",
  "topsites_form_edit_header": "Editar sitio favorito",
  "topsites_form_title_label": "Título",
  "topsites_form_title_placeholder": "Escribir un título",
  "topsites_form_url_label": "URL",
  "topsites_form_image_url_label": "URL da imaxe personalizada",
  "topsites_form_url_placeholder": "Escribir ou pegar un URL",
  "topsites_form_use_image_link": "Usar unha imaxe personalizada…",
  "topsites_form_preview_button": "Previsualizar",
  "topsites_form_add_button": "Engadir",
  "topsites_form_save_button": "Gardar",
  "topsites_form_cancel_button": "Cancelar",
  "topsites_form_url_validation": "Requírese un URL válido",
  "topsites_form_image_validation": "Produciuse un fallo ao cargar a imaxe. Probe un URL diferente.",
  "pocket_read_more": "Temas populares:",
  "pocket_read_even_more": "Ver máis historias",
  "highlights_empty_state": "Comece a navegar e aquí amosarémoslle algúns dos mellores artigos, vídeos e outras páxinas que visitara recentemente ou que engadira aos marcadores.",
  "topstories_empty_state": "Xa está ao día. Regrese máis tarde para ver máis historias de {provider}. Non pode agardar? Seleccione un tema popular e atopará máis historias interesantes da web.",
  "manual_migration_explanation2": "Probe Firefox cos marcadores, historial e contrasinais doutro navegador.",
  "manual_migration_cancel_button": "Non, grazas",
  "manual_migration_import_button": "Importar agora",
  "error_fallback_default_info": "Vaites, produciuse un erro ao cargar este contido.",
  "error_fallback_default_refresh_suggestion": "Actualice a páxina para tentalo de novo.",
  "section_menu_action_remove_section": "Retirar sección",
  "section_menu_action_collapse_section": "Contraer sección",
  "section_menu_action_expand_section": "Expandir sección",
  "section_menu_action_manage_section": "Xestionar sección",
  "section_menu_action_manage_webext": "Xestionar extensión",
  "section_menu_action_add_topsite": "Engadir sitio favorito",
  "section_menu_action_move_up": "Subir",
  "section_menu_action_move_down": "Baixar",
  "section_menu_action_privacy_notice": "Política de privacidade",
  "firstrun_title": "Leve o Firefox consigo",
  "firstrun_content": "Acceda aos seus marcadores, historial, contrasinais e outras configuracións en todos os seus dispositivos.",
  "firstrun_learn_more_link": "Obteña máis información sobre as contas Firefox",
  "firstrun_form_header": "Escriba o seu correo",
  "firstrun_form_sub_header": "para continuar a Firefox Sync.",
  "firstrun_email_input_placeholder": "Correo electrónico",
  "firstrun_extra_legal_links": "Ao continuar, acepta os {terms} e a {privacy}.",
  "firstrun_terms_of_service": "Termos do servizo",
  "firstrun_privacy_notice": "Política de privacidade",
  "firstrun_continue_to_login": "Continuar",
  "firstrun_skip_login": "Ignorar este paso"
};
